@@ -41,6 +41,7 @@ Manager *Manager::s_instance = Q_NULLPTR;
 Manager::Manager()
     : QObject()
     , m_watcher(KAMD_DBUS_SERVICE, QDBusConnection::sessionBus())
+    , m_service(new KAMD_DBUS_CLASS_INTERFACE(/*Application*/, Application, this))
     , m_activities(new KAMD_DBUS_CLASS_INTERFACE(Activities, Activities, this))
     , m_resources(new KAMD_DBUS_CLASS_INTERFACE(Resources, Resources, this))
     , m_resourcesLinking(new KAMD_DBUS_CLASS_INTERFACE(Resources/Linking, ResourcesLinking, this))
@@ -107,15 +108,11 @@ void Manager::serviceOwnerChanged(const QString &serviceName, const QString &old
         emit serviceStatusChanged(m_serviceRunning);
 
         if (m_serviceRunning) {
-            QDBusInterface service(KAMD_DBUS_SERVICE,
-                    "/ActivityManager",
-                    "org.kde.ActivityManager.Application",
-                    QDBusConnection::sessionBus(),
-                    Q_NULLPTR);
+            using namespace kamd::utils;
 
-            kamd::utils::continue_with(
-                DBusFuture::asyncCall<QString>(&service, "serviceVersion"),
-                [this] (const boost::optional<QString> &serviceVersion) {
+            continue_with(
+                DBusFuture::fromReply(m_service->serviceVersion()),
+                [this] (const optional_view<QString> &serviceVersion) {
                     // Test whether the service is older than the library.
                     // If it is, we need to end this
 
